==> eam-wshub-proxyclient-11.5-10-sources.jar: net/datastream/schemas/mp_entities/depreciation_001/RelativeStartPeriod.java <==

package net.datastream.schemas.mp_entities.depreciation_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.UOMID_Type;
import org.openapplications.oagis_segments.AMOUNT;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RELATIVESTART"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UOMID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "relativestart",
    "uomid"
})
@XmlRootElement(name = "RelativeStartPeriod")
public class RelativeStartPeriod {

    @XmlElement(name = "RELATIVESTART", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected AMOUNT relativestart;
    @XmlElement(name = "UOMID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected UOMID_Type uomid;

    /**
     * Obtient la valeur de la propriété relativestart.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getRELATIVESTART() {
        return relativestart;
    }

    /**
     * Définit la valeur de la propriété relativestart.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setRELATIVESTART(AMOUNT value) {
        this.relativestart = value;
    }

    /**
     * Obtient la valeur de la propriété uomid.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getUOMID() {
        return uomid;
    }

    /**
     * Définit la valeur de la propriété uomid.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setUOMID(UOMID_Type value) {
        this.uomid = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_entities/depreciation_001/RelativeStartPeriod.java <==

package net.datastream.schemas.mp_entities.depreciation_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.UOMID_Type;
import org.openapplications.oagis_segments.AMOUNT;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RELATIVESTART"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UOMID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "relativestart",
    "uomid"
})
@XmlRootElement(name = "RelativeStartPeriod")
public class RelativeStartPeriod {

    @XmlElement(name = "RELATIVESTART", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected AMOUNT relativestart;
    @XmlElement(name = "UOMID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected UOMID_Type uomid;

    /**
     * Gets the value of the relativestart property.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getRELATIVESTART() {
        return relativestart;
    }

    /**
     * Sets the value of the relativestart property.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setRELATIVESTART(AMOUNT value) {
        this.relativestart = value;
    }

    /**
     * Gets the value of the uomid property.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getUOMID() {
        return uomid;
    }

    /**
     * Sets the value of the uomid property.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setUOMID(UOMID_Type value) {
        this.uomid = value;
    }

}
